@@ -29,28 +29,34 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
+#include "robot_localization/navsat_transform.hpp"
 
-#include <robot_localization/filter_common.hpp>
-#include <robot_localization/filter_utilities.hpp>
-#include <robot_localization/navsat_conversions.hpp>
-#include <robot_localization/navsat_transform.hpp>
-#include <robot_localization/ros_filter_utilities.hpp>
-
-#include <GeographicLib/Geocentric.hpp>
-#include <GeographicLib/LocalCartesian.hpp>
-#include <nav_msgs/msg/odometry.hpp>
-#include <rclcpp/rclcpp.hpp>
-#include <sensor_msgs/msg/imu.hpp>
-#include <sensor_msgs/msg/nav_sat_fix.hpp>
-#include <tf2_geometry_msgs/tf2_geometry_msgs.hpp>
-
-#include <Eigen/Dense>
-
-#include <iostream>
+#include <chrono>
+#include <functional>
+#include <memory>
 #include <string>
 #include <vector>
-#include <memory>
-#include <utility>
+
+#include "angles/angles.h"
+#include "Eigen/Dense"
+#include "nav_msgs/msg/odometry.hpp"
+#include "rclcpp/qos.hpp"
+#include "rclcpp/rclcpp.hpp"
+#include "robot_localization/filter_common.hpp"
+#include "robot_localization/navsat_conversions.hpp"
+#include "robot_localization/ros_filter_utilities.hpp"
+#include "robot_localization/srv/from_ll.hpp"
+#include "robot_localization/srv/set_datum.hpp"
+#include "robot_localization/srv/to_ll.hpp"
+#include "sensor_msgs/msg/imu.hpp"
+#include "sensor_msgs/msg/nav_sat_fix.hpp"
+#include "tf2/LinearMath/Matrix3x3.h"
+#include "tf2/LinearMath/Quaternion.h"
+#include "tf2/LinearMath/Transform.h"
+#include "tf2/LinearMath/Vector3.h"
+#include "tf2_ros/buffer.h"
+#include "tf2_ros/transform_listener.h"
+#include "tf2_geometry_msgs/tf2_geometry_msgs.hpp"
 
 using std::placeholders::_1;
 using std::placeholders::_2;
@@ -116,7 +122,7 @@ NavSatTransform::NavSatTransform(const rclcpp::NodeOptions & options)
       "Please use 'broadcast_cartesian_transform' instead.");
   } else {
     broadcast_cartesian_transform_ =
-      this->declare_parameter("broadcast_utm_transform", broadcast_cartesian_transform_);
+      this->declare_parameter("broadcast_cartesian_transform", broadcast_cartesian_transform_);
   }
 
   broadcast_cartesian_transform_as_parent_frame_ =
@@ -401,8 +407,6 @@ bool NavSatTransform::toLLCallback(
   if (!transform_good_) {
     return false;
   }
-  // tf2::Vector3 point;
-  // tf2::fromMsg(request.map_point, point);
   tf2::Vector3 point(request->map_point.x, request->map_point.y,
     request->map_point.z);
   mapToLL(
@@ -676,9 +680,9 @@ void NavSatTransform::imuCallback(const sensor_msgs::msg::Imu::SharedPtr msg)
       // Apply the offset (making sure to bound them), and throw them in a
       // vector
       tf2::Vector3 rpy_angles(
-        filter_utilities::clampRotation(roll - roll_offset),
-        filter_utilities::clampRotation(pitch - pitch_offset),
-        filter_utilities::clampRotation(yaw - yaw_offset));
+        angles::normalize_angle(roll - roll_offset),
+        angles::normalize_angle(pitch - pitch_offset),
+        angles::normalize_angle(yaw - yaw_offset));
 
       // Now we need to rotate the roll and pitch by the yaw offset value.
       // Imagine a case where an IMU is mounted facing sideways. In that case
